@@ -46,7 +46,7 @@ from sure.six.moves import reduce
 if PY3:
     basestring = str
 
-version = '1.2.3'
+version = '1.2.4'
 
 
 not_here_error = \
@@ -409,7 +409,8 @@ NEGATIVES = [
     'shouldnot',
 ]
 
-class _IdentityAssertion(object):
+
+class IdentityAssertion(object):
     def __init__(self, assertion_builder):
         self._ab = assertion_builder
 
@@ -466,13 +467,18 @@ class AssertionBuilder(object):
 
     @assertionproperty
     def be(self):
-        return _IdentityAssertion(self)
+        import os
+        if os.getenv("DEBUG"):
+            import ipdb;ipdb.set_trace()
+
+
+        return IdentityAssertion(self)
 
     being = be
 
     @assertionproperty
     def not_be(self):
-        return _IdentityAssertion(self.should_not)
+        return IdentityAssertion(self.should_not)
 
     not_being = not_be
 
@@ -782,28 +788,6 @@ class AssertionBuilder(object):
 
         return _that.raises(*args, **kw)
 
-    @assertionproperty
-    def cool(self):
-        _that = AssertionHelper(self.obj,
-                     with_args=self._callable_args,
-                     and_kwargs=self._callable_kw)
-        if self.negative:
-            try:
-                return _that.raises(Exception)
-            except AssertionError:
-                raise AssertionError('The callable `{0}` was supposed to not be cool and throw an exception, but it is too cool for that'.format(self.obj.__name__))
-
-        try:
-            self.obj(*self._callable_args, **self._callable_kw)
-        except Exception as e:
-            raise AssertionError('The callable `{2}` should be cool but threw {0}: {1}'.format(
-                e.__class__.__name__,
-                str(e),
-                self.obj.__name__
-            ))
-
-        return True
-
     @assertionmethod
     def return_value(self, value):
         return_value = self.obj(*self._callable_args, **self._callable_kw)
@@ -892,10 +876,10 @@ if is_cpython and allows_new_syntax:
         def method(self):
             builder = AssertionBuilder(name, negative=False)
             instance = builder(self)
-            callable_args = getattr(self, '_callable_args', None)
+            callable_args = getattr(instance, '_callable_args', ())
             if callable_args:
                 instance._callable_args = callable_args
-            callable_kw = getattr(self, '_callable_kw', None)
+            callable_kw = getattr(instance, '_callable_kw', {})
             if callable_kw:
                 instance._callable_kw = callable_kw
             return instance
@@ -907,10 +891,10 @@ if is_cpython and allows_new_syntax:
         def method(self):
             builder = AssertionBuilder(name, negative=True)
             instance = builder(self)
-            callable_args = getattr(self, '_callable_args', None)
+            callable_args = getattr(instance, '_callable_args', ())
             if callable_args:
                 instance._callable_args = callable_args
-            callable_kw = getattr(self, '_callable_kw', None)
+            callable_kw = getattr(instance, '_callable_kw', {})
             if callable_kw:
                 instance._callable_kw = callable_kw
             return instance
